"""Egon is a lightweight framework for the development of parallelized data
analysis pipelines. See the online documentation at
https://mwvgroup.github.io/Egon/
"""

__version__ = '0.4.1'
__author__ = 'MWV Research Group'
__license__ = 'GPL 3.0'
